#!/usr/bin/env python
# -*- coding: utf-8 -*-
import sys,os,shutil
from PyQt4.QtCore import *
from PyQt4.QtGui import *

home = QDir.homePath()
temp = QDir.tempPath()+"/KS"

class SimpleWizard(QDialog):
    def __init__(self, parent=None):
        QDialog.__init__(self, parent)

        self.history = []
        self.numPages = 0
       
        
        self.cancelButton = QPushButton(self.tr("Cancel"))
        self.backButton = QPushButton(self.tr("< &Back"))
        self.nextButton = QPushButton(self.tr("Next >"))
        self.finishButton = QPushButton(self.tr("&Finish"))
    
        self.connect(self.cancelButton, SIGNAL("clicked()"), self, SLOT("reject()"))
        self.connect(self.backButton, SIGNAL("clicked()"), self.backButtonClicked)
        self.connect(self.nextButton, SIGNAL("clicked()"), self.nextButtonClicked)
        self.connect(self.finishButton, SIGNAL("clicked()"), self, SLOT("accept()"))
    
        buttonLayout = QHBoxLayout()
        buttonLayout.addStretch(1)
        buttonLayout.addWidget(self.cancelButton)
        buttonLayout.addWidget(self.backButton)
        buttonLayout.addWidget(self.nextButton)
        buttonLayout.addWidget(self.finishButton)
    
        self.mainLayout = QVBoxLayout()
        self.mainLayout.addLayout(buttonLayout)
        self.setLayout(self.mainLayout)

    def setButtonEnabled(self, enable):
        if len(self.history) == self.numPages:
            self.finishButton.setEnabled(enable)
        else:
            self.nextButton.setEnabled(enable)

    def setNumPages(self, n):
        self.numPages = n
        self.history.append(self.createPage(0))
        self.switchPage(0)

    def backButtonClicked(self):
        self.nextButton.setEnabled(True)
        self.finishButton.setEnabled(True)
    
        oldPage = self.history.pop()
        self.switchPage(oldPage)
        del oldPage

    def nextButtonClicked(self):
        self.nextButton.setEnabled(True)
        self.finishButton.setEnabled(len(self.history) == self.numPages - 1)
    
        oldPage = self.history[-1]
        self.history.append(self.createPage(len(self.history)))
        self.switchPage(oldPage)

    def switchPage(self, oldPage):
        if oldPage:
            oldPage.hide()
            self.mainLayout.removeWidget(oldPage)

        newPage = self.history[-1]
        self.mainLayout.insertWidget(0, newPage)
        newPage.show()
        newPage.setFocus()
    
        self.backButton.setEnabled(len(self.history) != 1)
        if len(self.history) == self.numPages:
            self.nextButton.setEnabled(False)
            self.finishButton.setDefault(True)
        else:
            self.nextButton.setDefault(True)
            self.finishButton.setEnabled(False)

        self.setWindowTitle(self.tr("New Splash Wizard - Step %1 of %2")
                                    .arg(len(self.history)).arg(self.numPages))
                       

class NewWizard(SimpleWizard):
    def __init__(self, ACTDIR, parent=None):
        SimpleWizard.__init__(self, parent)
        self.ACT = ACTDIR
        self.resize(500,360)
        self.setNumPages(5)

    def createPage(self, index):
        if index == 0:
            self.zeroPage = ZeroPage(self, self.ACT)
            return self.zeroPage
        elif index == 1:
            self.firstPage = FirstPage(self, self.ACT)
            return self.firstPage
        elif index == 2:
            self.secondPage = SecondPage(self, self.ACT)
            return self.secondPage
        elif index == 3:
            self.thirdPage = ThirdPage(self, self.ACT)
            return self.thirdPage
        elif index == 4:
            self.fourthPage = FourthPage(self, self.ACT)
            return self.fourthPage

        return 0

    def accept(self):
        NEW=str(temp+'/NEW')
        if os.path.exists(NEW):pass
        else:os.mkdir(NEW)
        print self.firstPage.back
        shutil.copy(self.firstPage.back,NEW)
        for n in range(8):shutil.copy(self.secondPage.newicons[n],NEW)
        shutil.copy('images/Theme.rc',NEW)
        QDialog.accept(self)
        
class ZeroPage(QWidget):
    def __init__(self, parent, ACTDIR):
        QWidget.__init__(self, parent)
        self.topLabel = QLabel(self.tr("<center><b>Welcome to the<br>"
                                       "new Splash Screen WIzard</b>"
                                             "<p>We will ask you a few questions and<br> "
                                             "then you will have your new Splash Screen.</center>"))
        self.topLabel.setWordWrap(False)
        self.topLabel.setAlignment(Qt.AlignTop| Qt.AlignCenter)
        iconLabel = QLabel(self)
        iconLabel.setPixmap(QPixmap ("%s/images/ksicon.png" %ACTDIR))
        
        horizontalLayout = QHBoxLayout()
        horizontalLayout.addWidget(iconLabel)
        horizontalLayout.addWidget(self.topLabel)

        self.setLayout(horizontalLayout)
        
class FourthPage(QWidget):
    def __init__(self, parent, ACTDIR):
        QWidget.__init__(self, parent)

        self.topLabel = QLabel(self.tr("<center><b>Wizard Complete</b>"
                                             "<p>All the needed information has been collected<br> "
                                             "you can now press 'Finish' and start editing.</center>"))
        self.topLabel.setWordWrap(False)
        self.topLabel.setAlignment(Qt.AlignTop| Qt.AlignCenter)
        iconLabel = QLabel(self)
        iconLabel.setPixmap(QPixmap ("%s/images/okbig.png" %ACTDIR))

        horizontalLayout = QHBoxLayout()
        horizontalLayout.addWidget(iconLabel)
        horizontalLayout.addWidget(self.topLabel)

        self.setLayout(horizontalLayout)

        

class FirstPage(QWidget):
    def __init__(self, parent, ACTDIR):
        QWidget.__init__(self, parent)
        self.ultimodir = QString()
        self.topLabel = QLabel(self.tr("<center><b>Background Image</b></center>"))
        self.topLabel.setWordWrap(False)
        self.back=''
        iconLabel = QLabel(self)
        iconLabel.setPixmap(QPixmap ("%s/images/back.png" %ACTDIR))
        iconBtn = QPushButton(self.tr("Load ..."))
        self.connect(iconBtn, SIGNAL('clicked()'), self.setBack)
        
        self.imgLabel = QLabel(self)
        self.imgLabel.setPixmap(QPixmap.scaled(QPixmap("%s/images/blank.png" %ACTDIR), 320, 240))
        self.imgLabel.setFrameStyle(QFrame.StyledPanel|QFrame.Sunken)
        
        rightLayout = QVBoxLayout()
        rightLayout.addWidget(self.topLabel)
        rightLayout.addWidget(self.imgLabel)
        rightLayout.addWidget(iconBtn)
        rightLayout.setAlignment(Qt.AlignTop| Qt.AlignCenter)
        

        horizontalLayout = QHBoxLayout()
        horizontalLayout.addWidget(iconLabel)
        horizontalLayout.addLayout(rightLayout)

        self.setLayout(horizontalLayout)

    def setBack(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Set Background Image"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        self.imgLabel.setPixmap(QPixmap.scaled(QPixmap(str(fname)), 320, 240))
        self.back=str(fname)
        
class SecondPage(QWidget):
    def __init__(self, parent, ACTDIR):
        QWidget.__init__(self, parent)
        self.ultimodir = QString()
        self.topLabel = QLabel(self.tr("<center><b>Icons</b>"
                                             "<p>Set the desired icon images "
                                             "for your new Splash Screen Theme.</center>"))
        self.topLabel.setWordWrap(False)

        iconLabel = QLabel(self)
        iconLabel.setPixmap(QPixmap ("%s/images/iconbig.png" %ACTDIR))
        iconBtn = QPushButton(self.tr("Load Full Set..."))
        self.connect(iconBtn, SIGNAL('clicked()'), self.setFull)

        self.newicons=["","","","","","","",""]
        self.icon1 = QToolButton()
        self.icon1.setIcon(QIcon("%s/images/1.png" %ACTDIR))
        self.icon1.setIconSize(QSize(64, 64))
        self.connect(self.icon1, SIGNAL('clicked()'), self.chgIcon1)
        self.icon2 = QToolButton()
        self.icon2.setIcon(QIcon("%s/images/2.png" %ACTDIR))
        self.icon2.setIconSize(QSize(64, 64))
        self.connect(self.icon2, SIGNAL('clicked()'), self.chgIcon2)
        self.icon3 = QToolButton()
        self.icon3.setIcon(QIcon("%s/images/3.png" %ACTDIR))
        self.icon3.setIconSize(QSize(64, 64))
        self.connect(self.icon3, SIGNAL('clicked()'), self.chgIcon3)
        self.icon4 = QToolButton()
        self.icon4.setIcon(QIcon("%s/images/4.png" %ACTDIR))
        self.icon4.setIconSize(QSize(64, 64))
        self.connect(self.icon4, SIGNAL('clicked()'), self.chgIcon4)
        self.icon5 = QToolButton()
        self.icon5.setIcon(QIcon("%s/images/5.png" %ACTDIR))
        self.icon5.setIconSize(QSize(64, 64))
        self.connect(self.icon5, SIGNAL('clicked()'), self.chgIcon5)
        self.icon6 = QToolButton()
        self.icon6.setIcon(QIcon("%s/images/6.png" %ACTDIR))
        self.icon6.setIconSize(QSize(64, 64))
        self.connect(self.icon6, SIGNAL('clicked()'), self.chgIcon6)
        self.icon7 = QToolButton()
        self.icon7.setIcon(QIcon("%s/images/7.png" %ACTDIR))
        self.icon7.setIconSize(QSize(64, 64))
        self.connect(self.icon7, SIGNAL('clicked()'), self.chgIcon7)
        self.icon8 = QToolButton()
        self.icon8.setIcon(QIcon("%s/images/8.png" %ACTDIR))
        self.icon8.setIconSize(QSize(64, 64))
        self.connect(self.icon8, SIGNAL('clicked()'), self.chgIcon8)

        authorLayout = QGridLayout()
        authorLayout.addWidget(self.icon1, 0, 0)
        authorLayout.addWidget(self.icon2, 0, 1)
        authorLayout.addWidget(self.icon3, 0, 2)
        authorLayout.addWidget(self.icon4, 0, 3)
        authorLayout.addWidget(self.icon5, 1, 0)
        authorLayout.addWidget(self.icon6, 1, 1)
        authorLayout.addWidget(self.icon7, 1, 2)
        authorLayout.addWidget(self.icon8, 1, 3)
        
        authorGroup = QGroupBox(self.tr("Icons"))
        authorGroup.setLayout(authorLayout)
        

        rightLayout = QVBoxLayout()
        rightLayout.addWidget(self.topLabel)
        rightLayout.addWidget(QLabel(""))
        rightLayout.addWidget(authorGroup)
        rightLayout.addWidget(iconBtn)
        rightLayout.setAlignment(Qt.AlignTop| Qt.AlignCenter)

        horizontalLayout = QHBoxLayout()
        horizontalLayout.addWidget(iconLabel)
        horizontalLayout.addLayout(rightLayout)

        self.setLayout(horizontalLayout)

    def chgIcon1(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Add/Change Icon"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.newicons[0]=str(fname)
        self.icon1.setIcon(QIcon(fname))
        
    def chgIcon2(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Add/Change Icon"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.newicons[1]=str(fname)
        self.icon2.setIcon(QIcon(fname))
        
    def chgIcon3(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Add/Change Icon"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.newicons[2]=str(fname)
        self.icon3.setIcon(QIcon(fname))
        
    def chgIcon4(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Add/Change Icon"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.newicons[3]=str(fname)
        self.icon4.setIcon(QIcon(fname))
        
    def chgIcon5(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Add/Change Icon"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.newicons[4]=str(fname)
        self.icon5.setIcon(QIcon(fname))
        
    def chgIcon6(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Add/Change Icon"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.newicons[5]=str(fname)
        self.icon6.setIcon(QIcon(fname))
        
    def chgIcon7(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Add/Change Icon"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.newicons[6]=str(fname)
        self.icon7.setIcon(QIcon(fname))
        
    def chgIcon8(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getOpenFileName(self,
                            self.tr("KSplasher - Add/Change Icon"), path,
                            self.tr("Pixmap Files (*.bmp *.jpg *.png *.xpm)"))
        if fname.isEmpty():
            return
        else: self.ultimodir = fname
        self.newicons[7]=str(fname)
        self.icon8.setIcon(QIcon(fname))

    def setFull(self):
        path = self.ultimodir \
            if not self.ultimodir.isEmpty() else home
        fname = QFileDialog.getExistingDirectory(self,
                            self.tr("KSplasher - Open Directory"), path, QFileDialog.ShowDirsOnly
                                                 | QFileDialog.DontResolveSymlinks)
        if fname.isEmpty(): return
        else: self.ultimodir = fname
        
        if os.path.exists(str(fname+'/1.png')):
            self.newicons[0]=str(fname+'/1.png')
            self.icon1.setIcon(QIcon(fname+'/1.png'))
        else: QMessageBox.warning(self, "KSplasher -- No Icon Folder",
                    "There are no Splash Icons in this directory")
        if os.path.exists(str(fname+'/2.png')):
            self.newicons[1]=str(fname+'/2.png')
            self.icon2.setIcon(QIcon(fname+'/2.png'))
        if os.path.exists(str(fname+'/3.png')):
            self.newicons[2]=str(fname+'/3.png')
            self.icon3.setIcon(QIcon(fname+'/3.png'))
        if os.path.exists(str(fname+'/4.png')):
            self.newicons[3]=str(fname+'/4.png')
            self.icon4.setIcon(QIcon(fname+'/4.png'))
        if os.path.exists(str(fname+'/5.png')):
            self.newicons[4]=str(fname+'/5.png')
            self.icon5.setIcon(QIcon(fname+'/5.png'))
        if os.path.exists(str(fname+'/6.png')):
            self.newicons[5]=str(fname+'/6.png')
            self.icon6.setIcon(QIcon(fname+'/6.png'))
        if os.path.exists(str(fname+'/7.png')):
            self.newicons[6]=str(fname+'/7.png')
            self.icon7.setIcon(QIcon(fname+'/7.png'))
        if os.path.exists(str(fname+'/8.png')):
            self.newicons[7]=str(fname+'/8.png')
            self.icon8.setIcon(QIcon(fname+'/8.png'))

        
class ThirdPage(QWidget):
    def __init__(self, parent, ACTDIR):
        QWidget.__init__(self, parent)
        
        self.topLabel = QLabel(self.tr("<center><b>Author Information</b>"
                                             "<p>Set up theme name, description "
                                             "and personal author information.</center>"))
        self.topLabel.setWordWrap(False)
        
        iconLabel = QLabel(self)
        iconLabel.setPixmap(QPixmap ("%s/images/authorbig.png" %ACTDIR))
        
        nameLabel = QLabel(self.tr("Theme Name:"))
        self.nameEdit = QLineEdit()
        desLabel = QLabel(self.tr("Description:"))
        self.desEdit = QLineEdit()
        verLabel = QLabel(self.tr("Version:"))
        self.verEdit = QLineEdit()
        autLabel = QLabel(self.tr("Author:"))
        self.autEdit = QLineEdit()       
        emLabel = QLabel(self.tr("E-mail:"))
        self.emEdit = QLineEdit()
        pageLabel = QLabel(self.tr("Homepage:"))
        self.pageEdit = QLineEdit()

        authorLayout = QGridLayout()
        authorLayout.addWidget(nameLabel, 0, 0)
        authorLayout.addWidget(self.nameEdit, 0, 1, 1, 10)
        authorLayout.addWidget(desLabel, 1, 0)
        authorLayout.addWidget(self.desEdit, 1, 1, 1, 10)
        authorLayout.addWidget(verLabel, 2, 0)
        authorLayout.addWidget(self.verEdit, 2, 1, 1, 2)
        authorLayout.addWidget(autLabel, 3, 0)
        authorLayout.addWidget(self.autEdit, 3, 1, 1, 10)
        authorLayout.addWidget(emLabel, 4, 0)
        authorLayout.addWidget(self.emEdit, 4, 1, 1, 10)
        authorLayout.addWidget(pageLabel, 5, 0)
        authorLayout.addWidget(self.pageEdit, 5, 1, 1, 10)

        authorGroup = QGroupBox(self.tr("Author Information"))
        authorGroup.setLayout(authorLayout)

        rightLayout = QVBoxLayout()
        rightLayout.addWidget(self.topLabel)
        rightLayout.addWidget(QLabel(""))
        rightLayout.addWidget(authorGroup)
        rightLayout.setAlignment(Qt.AlignTop| Qt.AlignCenter)

        horizontalLayout = QHBoxLayout()
        horizontalLayout.addWidget(iconLabel)
        horizontalLayout.addLayout(rightLayout)

        self.setLayout(horizontalLayout)
        

if __name__ == '__main__':
    app = QApplication(sys.argv)
    wizard = NewWizard()
    wizard.exec_()
